Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(26)

Unified Diff: sdk/lib/_internal/compiler/implementation/compiler.dart

Issue 11299220: Add @JSName annotation for native fields and methods. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: sdk/lib/_internal/compiler/implementation/compiler.dart
diff --git a/sdk/lib/_internal/compiler/implementation/compiler.dart b/sdk/lib/_internal/compiler/implementation/compiler.dart
index e770cff2319056437c6eff12c693a9ed17a56240..996d52f5ed54622fc7bb0589e764cc020310dd87 100644
--- a/sdk/lib/_internal/compiler/implementation/compiler.dart
+++ b/sdk/lib/_internal/compiler/implementation/compiler.dart
@@ -493,8 +493,11 @@ abstract class Compiler implements DiagnosticListener {
|| libraryName == 'dart:math'
|| libraryName == 'dart:html'
|| libraryName == 'dart:svg') {
- if (libraryName == 'dart:html' || libraryName == 'dart:mirrors') {
- // dart:html needs access to convertDartClosureToJS.
+ if (libraryName == 'dart:html' ||
+ libraryName == 'dart:svg' ||
+ libraryName == 'dart:mirrors') {
+ // dart:html and dart:svg need access to convertDartClosureToJS and
+ // annotation classes.
// dart:mirrors needs access to the Primitives class.
importHelperLibrary(library);
}

Powered by Google App Engine
This is Rietveld 408576698